==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/FunnelSliceEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FunnelSliceEventArgsDescription } from "./FunnelSliceEventArgsDescription";
/**
 * @hidden
 */
var FunnelSliceEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(FunnelSliceEventArgsDescriptionMetadata, _super);
    function FunnelSliceEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    FunnelSliceEventArgsDescriptionMetadata.b = function (a) {
        if (FunnelSliceEventArgsDescriptionMetadata.a == null) {
            FunnelSliceEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            FunnelSliceEventArgsDescriptionMetadata.c(FunnelSliceEventArgsDescriptionMetadata.a);
        }
        if (a.j(FunnelSliceEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(FunnelSliceEventArgsDescriptionMetadata.a);
    };
    FunnelSliceEventArgsDescriptionMetadata.c = function (a) {
        a.item("Index", "Number:int");
        a.item("Bounds", "Rect");
        a.item("ItemRef", "(w:Item,wf:Item)DataRef");
    };
    FunnelSliceEventArgsDescriptionMetadata.d = function (a) {
        FunnelSliceEventArgsDescriptionMetadata.b(a);
        a.aa("FunnelSliceEventArgs", function () { return new FunnelSliceEventArgsDescription(); });
        a.z("FunnelSliceEventArgs", FunnelSliceEventArgsDescriptionMetadata.a);
    };
    FunnelSliceEventArgsDescriptionMetadata.$t = markType(FunnelSliceEventArgsDescriptionMetadata, 'FunnelSliceEventArgsDescriptionMetadata');
    FunnelSliceEventArgsDescriptionMetadata.a = null;
    return FunnelSliceEventArgsDescriptionMetadata;
}(Base));
export { FunnelSliceEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/FunnelSliceEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FunnelSliceEventArgsDescription } from "./FunnelSliceEventArgsDescription";
/**
 * @hidden
 */
var FunnelSliceEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(FunnelSliceEventArgsDescriptionMetadata, _super);
    function FunnelSliceEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    FunnelSliceEventArgsDescriptionMetadata.b = function (a) {
        if (FunnelSliceEventArgsDescriptionMetadata.a == null) {
            FunnelSliceEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            FunnelSliceEventArgsDescriptionMetadata.c(FunnelSliceEventArgsDescriptionMetadata.a);
        }
        if (a.k(FunnelSliceEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(FunnelSliceEventArgsDescriptionMetadata.a);
    };
    FunnelSliceEventArgsDescriptionMetadata.c = function (a) {
        a.item("Index", "Number:int");
        a.item("Bounds", "Rect");
        a.item("ItemRef", "(w:Item,wf:Item)DataRef");
    };
    FunnelSliceEventArgsDescriptionMetadata.d = function (a) {
        FunnelSliceEventArgsDescriptionMetadata.b(a);
        a.ac("FunnelSliceEventArgs", function () { return new FunnelSliceEventArgsDescription(); });
        a.ab("FunnelSliceEventArgs", FunnelSliceEventArgsDescriptionMetadata.a);
    };
    FunnelSliceEventArgsDescriptionMetadata.$t = markType(FunnelSliceEventArgsDescriptionMetadata, 'FunnelSliceEventArgsDescriptionMetadata');
    FunnelSliceEventArgsDescriptionMetadata.a = null;
    return FunnelSliceEventArgsDescriptionMetadata;
}(Base));
export { FunnelSliceEventArgsDescriptionMetadata };
